@@ -1,4 +1,5 @@
 context("US Cities")
+require(sf)
 
 test_that("Cities function can take multiple kinds of input", {
   expect_gt(nrow(us_cities()), 1)
@@ -11,13 +12,11 @@ test_that("Cities function can take multiple kinds of input", {
 })
 
 test_that("Cities function returns an sf data.frame", {
-  expect_is(us_cities(1876), "data.frame")
-  expect_is(us_cities(1976), "sf")
+  expect_s3_class(us_cities(1876), "data.frame")
+  expect_s3_class(us_cities(1976), "sf")
 })
 
 test_that("Cities function can be filtered by state", {
-  nc <- us_cities(2010, states = "NC")
-  sc <- us_cities(1876, states = "South Carolina")
-  expect_identical(unique(nc$state_name), "North Carolina")
-  expect_identical(unique(sc$state_abbr), "SC")
+  expect_identical(unique(us_cities(2010, states = "NC")$state_name), "North Carolina")
+  expect_identical(unique(us_cities(1876, states = "South Carolina")$state_abbr), "SC")
 })
